==> lxqt-notificationd_2.2.0.orig.tar.xz: lxqt-notificationd-2.2.0/config/translations/lxqt-config-notificationd_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>AdvancedSettings</name>
    <message>
        <location filename="../advancedsettings.ui" line="39"/>
        <location filename="../advancedsettings.ui" line="49"/>
        <source>Use the top of the notification as shown.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="42"/>
        <source>Ignore these notifications:</source>
        <translation>Αγνόηση αυτών των ειδοποιήσεων:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="67"/>
        <source>Duration</source>
        <translation>Διάρκεια</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="79"/>
        <source>Some notifications set their own on-screen duration.</source>
        <translation>Μερικές ειδοποιήσεις καθορίζουν τη δική τους διάρκεια εμφάνισης.</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="91"/>
        <source>Default duration:</source>
        <translation>Διάρκεια εξ ορισμού:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="98"/>
        <source> sec</source>
        <translation> δευτ</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="126"/>
        <source>Screen</source>
        <translation>Οθόνη</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="132"/>
        <source>When unchecked the notification will always show on primary screen</source>
        <translation>Όταν δεν είναι επιλεγμένο η ειδοποίηση θα εμφανίζεται πάντα στην κυρίως οθόνη</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="135"/>
        <source>Show notifications on screen with the mouse</source>
        <translation>Εμφάνιση των ειδοποιήσεων στην οθόνη με το ποντίκι</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="145"/>
        <source>Do Not Disturb</source>
        <translation>Μην ενοχλείτε</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="151"/>
        <source>Only save notifications</source>
        <translation>Να γίνεται μόνο αποθήκευση των ειδοποιήσεων</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="17"/>
        <source>Unattended Notifications</source>
        <translation>Ανεπίβλεπτες ειδοποιήσεις</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="25"/>
        <source>How many to save:</source>
        <translation>Αριθμός αποθηκευμένων ειδοποιήσεων:</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="17"/>
        <source>Sizes</source>
        <translation>Μεγέθη</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="25"/>
        <source>Width:</source>
        <translation>Πλάτος:</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="32"/>
        <location filename="../basicsettings.ui" line="56"/>
        <source> px</source>
        <translation> εικ</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="49"/>
        <source>Spacing:</source>
        <translation>Διαπόσταση:</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="68"/>
        <source>Position on screen</source>
        <translation>Θέση στην οθόνη</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="227"/>
        <source>Preview</source>
        <translation>Προεπισκόπηση</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="65"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; notifications daemon is slow to respond.
Keep trying to connect…</source>
        <translation>&lt;b&gt;Προειδοποίηση:&lt;/b&gt; ο δαίμονας ειδοποιήσεων αργεί να ανταποκριθεί.
Συνεχίζεται η προσπάθεια σύνδεσης…</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="74"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
A fallback will be used.</source>
        <translation>&lt;b&gt;Προειδοποίηση:&lt;/b&gt; Δεν εκτελείται κάποιος δαίμονας ειδοποιήσεων
Θα χρησιμοποιηθεί η ανακατεύθυνση.</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="77"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
These settings won&apos;t have any effect on it!</source>
        <translation>&lt;b&gt;Προειδοποίηση:&lt;/b&gt; Εκτελείται ένας δαίμονας ειδοποιήσεων τρίτων (%1).
Αυτές οι ρυθμίσεις δεν θα έχουν κάποια επίδραση σε αυτόν!</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="142"/>
        <source>at top left</source>
        <translation>άνω αριστερά</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="144"/>
        <source>at top center</source>
        <translation>στην κορυφή στο κέντρο</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="146"/>
        <source>at top right</source>
        <translation>άνω δεξιά</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="148"/>
        <source>at center left</source>
        <translation>στο κέντρο αριστερά</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="150"/>
        <source>at center right</source>
        <translation>στο κέντρο δεξιά</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="152"/>
        <source>at bottom left</source>
        <translation>στην βάση αριστερά</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="154"/>
        <source>at bottom center</source>
        <translation>στην βάση στο κέντρο</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="156"/>
        <source>at bottom right</source>
        <translation>στην βάση δεξιά</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="158"/>
        <source>Notification demo </source>
        <translation>Επίδειξη ειδοποιήσεων </translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="159"/>
        <source>This is a test notification.
 All notifications will now appear here on LXQt.</source>
        <translation>Αυτή είναι μια δοκιμαστική ειδοποίηση.
 Όλες οι ειδοποιήσεις στο LXQt θα εμφανίζονται εδώ.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="41"/>
        <source>Desktop Notifications</source>
        <translation>Ειδοποιήσεις επιφάνειας εργασίας</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="44"/>
        <source>General Settings</source>
        <translation>Γενικές ρυθμίσεις</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="48"/>
        <source>Appearance</source>
        <translation>Εμφάνιση</translation>
    </message>
</context>
</TS>

==> lxqt-notificationd_2.3.0.orig.tar.xz: lxqt-notificationd-2.3.0/config/translations/lxqt-config-notificationd_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>AdvancedSettings</name>
    <message>
        <location filename="../advancedsettings.ui" line="85"/>
        <location filename="../advancedsettings.ui" line="95"/>
        <source>Use the top of the notification as shown.</source>
        <translation>Χρησιμοποιήστε το επάνω μέρος της ειδοποίησης, όπως φαίνεται.</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="88"/>
        <source>Ignore these notifications:</source>
        <translation>Αγνόηση αυτών των ειδοποιήσεων:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="17"/>
        <source>Duration</source>
        <translation>Διάρκεια</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="29"/>
        <source>Some notifications set their own on-screen duration.</source>
        <translation>Μερικές ειδοποιήσεις καθορίζουν τη δική τους διάρκεια εμφάνισης.</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="41"/>
        <source>Default duration:</source>
        <translation>Διάρκεια εξ ορισμού:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="48"/>
        <source> sec</source>
        <translation> δευτ</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="129"/>
        <source>Screen</source>
        <translation>Οθόνη</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="135"/>
        <source>When unchecked the notification will always show on primary screen</source>
        <translation>Όταν δεν είναι επιλεγμένο η ειδοποίηση θα εμφανίζεται πάντα στην κυρίως οθόνη</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="138"/>
        <source>Show notifications on screen with the mouse</source>
        <translation>Εμφάνιση των ειδοποιήσεων στην οθόνη με το ποντίκι</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="113"/>
        <source>Do Not Disturb</source>
        <translation>Μην ενοχλείτε</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="119"/>
        <source>Only save notifications</source>
        <translation>Να γίνεται μόνο αποθήκευση των ειδοποιήσεων</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="63"/>
        <source>Unattended Notifications</source>
        <translation>Ανεπίβλεπτες ειδοποιήσεις</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="71"/>
        <source>How many to save:</source>
        <translation>Αριθμός αποθηκευμένων ειδοποιήσεων:</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="17"/>
        <source>Sizes</source>
        <translation>Μεγέθη</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="25"/>
        <source>Width:</source>
        <translation>Πλάτος:</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="32"/>
        <location filename="../basicsettings.ui" line="56"/>
        <source> px</source>
        <translation> εικ</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="49"/>
        <source>Spacing:</source>
        <translation>Διαπόσταση:</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="68"/>
        <source>Position on screen</source>
        <translation>Θέση στην οθόνη</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="227"/>
        <source>Preview</source>
        <translation>Προεπισκόπηση</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="65"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; notifications daemon is slow to respond.
Keep trying to connect…</source>
        <translation>&lt;b&gt;Προειδοποίηση:&lt;/b&gt; ο δαίμονας ειδοποιήσεων αργεί να ανταποκριθεί.
Συνεχίζεται η προσπάθεια σύνδεσης…</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="74"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
A fallback will be used.</source>
        <translation>&lt;b&gt;Προειδοποίηση:&lt;/b&gt; Δεν εκτελείται κάποιος δαίμονας ειδοποιήσεων
Θα χρησιμοποιηθεί η ανακατεύθυνση.</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="77"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
These settings won&apos;t have any effect on it!</source>
        <translation>&lt;b&gt;Προειδοποίηση:&lt;/b&gt; Εκτελείται ένας δαίμονας ειδοποιήσεων τρίτων (%1).
Αυτές οι ρυθμίσεις δεν θα έχουν κάποια επίδραση σε αυτόν!</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="142"/>
        <source>at top left</source>
        <translation>άνω αριστερά</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="144"/>
        <source>at top center</source>
        <translation>στην κορυφή στο κέντρο</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="146"/>
        <source>at top right</source>
        <translation>άνω δεξιά</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="148"/>
        <source>at center left</source>
        <translation>στο κέντρο αριστερά</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="150"/>
        <source>at center right</source>
        <translation>στο κέντρο δεξιά</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="152"/>
        <source>at bottom left</source>
        <translation>στην βάση αριστερά</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="154"/>
        <source>at bottom center</source>
        <translation>στην βάση στο κέντρο</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="156"/>
        <source>at bottom right</source>
        <translation>στην βάση δεξιά</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="158"/>
        <source>Notification demo </source>
        <translation>Επίδειξη ειδοποιήσεων </translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="159"/>
        <source>This is a test notification.
 All notifications will now appear here on LXQt.</source>
        <translation>Αυτή είναι μια δοκιμαστική ειδοποίηση.
 Όλες οι ειδοποιήσεις στο LXQt θα εμφανίζονται εδώ.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="41"/>
        <source>Desktop Notifications</source>
        <translation>Ειδοποιήσεις επιφάνειας εργασίας</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="44"/>
        <source>General Settings</source>
        <translation>Γενικές ρυθμίσεις</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="48"/>
        <source>Appearance</source>
        <translation>Εμφάνιση</translation>
    </message>
</context>
</TS>
